Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BindContext ¶
type BindContext struct {
SchedCtx *SchedulingContext
// Extensions stores extra bind context information of each plugin
Extensions map[string]cache.BindContextExtension
}
type PodScheduleResult ¶
type PodScheduleResult struct {
SchedCtx *SchedulingContext
BindContext *BindContext
SuggestedNodes []*api.NodeInfo
ScheduleCycleUID types.UID
}
PodScheduleResult contains the scheduling result for a pod
type SchedulingContext ¶
type SchedulingContext struct {
// Task is the task to be scheduled
Task *api.TaskInfo
// QueuedPodInfo is the original pod info from the scheduling queue
QueuedPodInfo *framework.QueuedPodInfo
// NodesInShard is the nodes in shard of current scheduler
NodesInShard sets.Set[string]
}
SchedulingContext contains all information needed for scheduling a task
Click to show internal directories.
Click to hide internal directories.